@@ -2,12 +2,22 @@ from __future__ import print_function, division, absolute_import
 
 from . import config
 from dask.config import config
+from .actor import Actor, ActorFuture
 from .core import connect, rpc
 from .deploy import LocalCluster, Adaptive
 from .diagnostics import progress
-from .client import (Client, Executor, CompatibleExecutor,
-                     wait, as_completed, default_client, fire_and_forget,
-                     Future, futures_of)
+from .client import (
+    Client,
+    Executor,
+    CompatibleExecutor,
+    wait,
+    as_completed,
+    default_client,
+    fire_and_forget,
+    Future,
+    futures_of,
+    get_task_stream,
+)
 from .lock import Lock
 from .nanny import Nanny
 from .pubsub import Pub, Sub
@@ -22,7 +32,8 @@ from .worker_client import local_client, worker_client
 from tornado.gen import TimeoutError
 
 from ._version import get_versions
+
 versions = get_versions()
-__version__ = versions['version']
-__git_revision__ = versions['full-revisionid']
+__version__ = versions["version"]
+__git_revision__ = versions["full-revisionid"]
 del get_versions, versions
