@@ -21,10 +21,14 @@ from .node import ServerNode
 from .process import AsyncProcess
 from .proctitle import enable_proctitle_on_children
 from .security import Security
-from .utils import (get_ip, mp_context, silence_logging, json_load_robust,
-        PeriodicCallback)
-from .worker import _ncores, run, parse_memory_limit
-
+from .utils import (
+    get_ip,
+    mp_context,
+    silence_logging,
+    json_load_robust,
+    PeriodicCallback,
+)
+from .worker import _ncores, run, parse_memory_limit, Worker
 
 logger = logging.getLogger(__name__)
 
@@ -35,21 +39,43 @@ class Nanny(ServerNode):
     The nanny spins up Worker processes, watches then, and kills or restarts
     them as necessary.
     """
+
     process = None
     status = None
 
-    def __init__(self, scheduler_ip=None, scheduler_port=None,
-                 scheduler_file=None, worker_port=0,
-                 ncores=None, loop=None, local_dir=None, services=None,
-                 name=None, memory_limit='auto', reconnect=True,
-                 validate=False, quiet=False, resources=None, silence_logs=None,
-                 death_timeout=None, preload=(), preload_argv=[], security=None,
-                 contact_address=None, listen_address=None, **kwargs):
+    def __init__(
+        self,
+        scheduler_ip=None,
+        scheduler_port=None,
+        scheduler_file=None,
+        worker_port=0,
+        ncores=None,
+        loop=None,
+        local_dir="dask-worker-space",
+        services=None,
+        name=None,
+        memory_limit="auto",
+        reconnect=True,
+        validate=False,
+        quiet=False,
+        resources=None,
+        silence_logs=None,
+        death_timeout=None,
+        preload=(),
+        preload_argv=[],
+        security=None,
+        contact_address=None,
+        listen_address=None,
+        worker_class=None,
+        env=None,
+        **worker_kwargs
+    ):
+
         if scheduler_file:
             cfg = json_load_robust(scheduler_file)
-            self.scheduler_addr = cfg['address']
-        elif scheduler_ip is None and dask.config.get('scheduler-address'):
-            self.scheduler_addr = dask.config.get('scheduler-address')
+            self.scheduler_addr = cfg["address"]
+        elif scheduler_ip is None and dask.config.get("scheduler-address"):
+            self.scheduler_addr = dask.config.get("scheduler-address")
         elif scheduler_port is None:
             self.scheduler_addr = coerce_to_address(scheduler_ip)
         else:
@@ -62,14 +88,19 @@ class Nanny(ServerNode):
         self.death_timeout = death_timeout
         self.preload = preload
         self.preload_argv = preload_argv
+        self.Worker = Worker if worker_class is None else worker_class
+        self.env = env or {}
+        self.worker_kwargs = worker_kwargs
 
         self.contact_address = contact_address
-        self.memory_terminate_fraction = dask.config.get('distributed.worker.memory.terminate')
+        self.memory_terminate_fraction = dask.config.get(
+            "distributed.worker.memory.terminate"
+        )
 
         self.security = security or Security()
         assert isinstance(self.security, Security)
-        self.connection_args = self.security.get_connection_args('worker')
-        self.listen_args = self.security.get_listen_args('worker')
+        self.connection_args = self.security.get_connection_args("worker")
+        self.listen_args = self.security.get_listen_args("worker")
 
         self.local_dir = local_dir
 
@@ -86,23 +117,25 @@ class Nanny(ServerNode):
             silence_logging(level=silence_logs)
         self.silence_logs = silence_logs
 
-        handlers = {'instantiate': self.instantiate,
-                    'kill': self.kill,
-                    'restart': self.restart,
-                    # cannot call it 'close' on the rpc side for naming conflict
-                    'terminate': self._close,
-                    'run': self.run}
+        handlers = {
+            "instantiate": self.instantiate,
+            "kill": self.kill,
+            "restart": self.restart,
+            # cannot call it 'close' on the rpc side for naming conflict
+            "terminate": self._close,
+            "run": self.run,
+        }
 
-        super(Nanny, self).__init__(handlers, io_loop=self.loop,
-                                    connection_args=self.connection_args,
-                                    **kwargs)
+        super(Nanny, self).__init__(
+            handlers, io_loop=self.loop, connection_args=self.connection_args
+        )
 
         if self.memory_limit:
             pc = PeriodicCallback(self.memory_monitor, 100, io_loop=self.loop)
-            self.periodic_callbacks['memory'] = pc
+            self.periodic_callbacks["memory"] = pc
 
         self._listen_address = listen_address
-        self.status = 'init'
+        self.status = "init"
 
     def __repr__(self):
         return "<Nanny: %s, threads: %d>" % (self.worker_address, self.ncores)
@@ -115,11 +148,18 @@ class Nanny(ServerNode):
         if worker_address is None:
             return
 
-        allowed_errors = (gen.TimeoutError, CommClosedError, EnvironmentError, RPCClosed)
+        allowed_errors = (
+            gen.TimeoutError,
+            CommClosedError,
+            EnvironmentError,
+            RPCClosed,
+        )
         try:
-            yield gen.with_timeout(timedelta(seconds=timeout),
-                                   self.scheduler.unregister(address=self.worker_address),
-                                   quiet_exceptions=allowed_errors)
+            yield gen.with_timeout(
+                timedelta(seconds=timeout),
+                self.scheduler.unregister(address=self.worker_address),
+                quiet_exceptions=allowed_errors,
+            )
         except allowed_errors:
             pass
 
@@ -138,30 +178,34 @@ class Nanny(ServerNode):
         # XXX Factor this out
         if not addr_or_port:
             # Default address is the required one to reach the scheduler
-            self.listen(get_local_address_for(self.scheduler.address),
-                        listen_args=self.listen_args)
+            self.listen(
+                get_local_address_for(self.scheduler.address),
+                listen_args=self.listen_args,
+            )
             self.ip = get_address_host(self.address)
         elif isinstance(addr_or_port, int):
             # addr_or_port is an integer => assume TCP
-            self.ip = get_ip(
-                get_address_host(self.scheduler.address)
-            )
-            self.listen((self.ip, addr_or_port),
-                        listen_args=self.listen_args)
+            self.ip = get_ip(get_address_host(self.scheduler.address))
+            self.listen((self.ip, addr_or_port), listen_args=self.listen_args)
         else:
             self.listen(addr_or_port, listen_args=self.listen_args)
             self.ip = get_address_host(self.address)
 
-        logger.info('        Start Nanny at: %r', self.address)
+        logger.info("        Start Nanny at: %r", self.address)
         response = yield self.instantiate()
-        if response == 'running':
+        if response == "running":
             assert self.worker_address
-            self.status = 'running'
+            self.status = "running"
         else:
             yield self._close()
 
         self.start_periodic_callbacks()
 
+        raise gen.Return(self)
+
+    def __await__(self):
+        return self._start().__await__()
+
     def start(self, addr_or_port=0):
         self.loop.add_callback(self._start, addr_or_port)
 
@@ -174,7 +218,7 @@ class Nanny(ServerNode):
         """
         self.auto_restart = False
         if self.process is None:
-            raise gen.Return('OK')
+            raise gen.Return("OK")
 
         deadline = self.loop.time() + timeout
         yield self.process.kill(timeout=0.8 * (deadline - self.loop.time()))
@@ -190,42 +234,49 @@ class Nanny(ServerNode):
             start_arg = self._listen_address
         else:
             host = self.listener.bound_address[0]
-            start_arg = self.listener.prefix + unparse_host_port(host,
-                    self._given_worker_port)
+            start_arg = self.listener.prefix + unparse_host_port(
+                host, self._given_worker_port
+            )
 
         if self.process is None:
+            worker_kwargs = dict(
+                scheduler_ip=self.scheduler_addr,
+                ncores=self.ncores,
+                local_dir=self.local_dir,
+                services=self.services,
+                service_ports={"nanny": self.port},
+                name=self.name,
+                memory_limit=self.memory_limit,
+                reconnect=self.reconnect,
+                resources=self.resources,
+                validate=self.validate,
+                silence_logs=self.silence_logs,
+                death_timeout=self.death_timeout,
+                preload=self.preload,
+                preload_argv=self.preload_argv,
+                security=self.security,
+                contact_address=self.contact_address,
+            )
+            worker_kwargs.update(self.worker_kwargs)
             self.process = WorkerProcess(
-                worker_args=(self.scheduler_addr,),
-                worker_kwargs=dict(ncores=self.ncores,
-                                   local_dir=self.local_dir,
-                                   services=self.services,
-                                   service_ports={'nanny': self.port},
-                                   name=self.name,
-                                   memory_limit=self.memory_limit,
-                                   reconnect=self.reconnect,
-                                   resources=self.resources,
-                                   validate=self.validate,
-                                   silence_logs=self.silence_logs,
-                                   death_timeout=self.death_timeout,
-                                   preload=self.preload,
-                                   preload_argv=self.preload_argv,
-                                   security=self.security,
-                                   contact_address=self.contact_address),
+                worker_args=tuple(),
+                worker_kwargs=worker_kwargs,
                 worker_start_args=(start_arg,),
                 silence_logs=self.silence_logs,
                 on_exit=self._on_exit,
+                worker=self.Worker,
+                env=self.env,
             )
 
         self.auto_restart = True
         if self.death_timeout:
             try:
                 result = yield gen.with_timeout(
-                        timedelta(seconds=self.death_timeout),
-                        self.process.start()
+                    timedelta(seconds=self.death_timeout), self.process.start()
                 )
             except gen.TimeoutError:
                 yield self._close(timeout=self.death_timeout)
-                raise gen.Return('timed out')
+                raise gen.Return("timed out")
         else:
             result = yield self.process.start()
         raise gen.Return(result)
@@ -244,13 +295,13 @@ class Nanny(ServerNode):
             yield gen.with_timeout(timedelta(seconds=timeout), _())
         except gen.TimeoutError:
             logger.error("Restart timed out, returning before finished")
-            raise gen.Return('timed out')
+            raise gen.Return("timed out")
         else:
-            raise gen.Return('OK')
+            raise gen.Return("OK")
 
     def memory_monitor(self):
-        """ Track worker's memory.  Restart if it goes above 95% """
-        if self.status != 'running':
+        """ Track worker's memory.  Restart if it goes above terminate fraction """
+        if self.status != "running":
             return
         process = self.process.process
         if process is None:
@@ -262,18 +313,21 @@ class Nanny(ServerNode):
         memory = proc.memory_info().rss
         frac = memory / self.memory_limit
         if self.memory_terminate_fraction and frac > self.memory_terminate_fraction:
-            logger.warning("Worker exceeded 95% memory budget.  Restarting")
+            logger.warning(
+                "Worker exceeded %d%% memory budget. Restarting",
+                100 * self.memory_terminate_fraction,
+            )
             process.terminate()
 
     def is_alive(self):
-        return self.process is not None and self.process.status == 'running'
+        return self.process is not None and self.process.status == "running"
 
     def run(self, *args, **kwargs):
         return run(self, *args, **kwargs)
 
     @gen.coroutine
     def _on_exit(self, exitcode):
-        if self.status not in ('closing', 'closed'):
+        if self.status not in ("closing", "closed"):
             try:
                 yield self.scheduler.unregister(address=self.worker_address)
             except (EnvironmentError, CommClosedError):
@@ -282,13 +336,14 @@ class Nanny(ServerNode):
                     return
 
             try:
-                if self.status not in ('closing', 'closed'):
+                if self.status not in ("closing", "closed"):
                     if self.auto_restart:
                         logger.warning("Restarting worker")
                         yield self.instantiate()
             except Exception:
-                logger.error("Failed to restart worker after its process exited",
-                             exc_info=True)
+                logger.error(
+                    "Failed to restart worker after its process exited", exc_info=True
+                )
 
     @property
     def pid(self):
@@ -299,9 +354,9 @@ class Nanny(ServerNode):
         """
         Close the worker process, stop all comms.
         """
-        if self.status in ('closing', 'closed'):
-            raise gen.Return('OK')
-        self.status = 'closing'
+        if self.status in ("closing", "closed"):
+            raise gen.Return("OK")
+        self.status = "closing"
         logger.info("Closing Nanny at %r", self.address)
         self.stop()
         try:
@@ -312,21 +367,30 @@ class Nanny(ServerNode):
         self.process = None
         self.rpc.close()
         self.scheduler.close_rpc()
-        self.status = 'closed'
-        raise gen.Return('OK')
+        self.status = "closed"
+        raise gen.Return("OK")
 
 
 class WorkerProcess(object):
-
-    def __init__(self, worker_args, worker_kwargs, worker_start_args,
-                 silence_logs, on_exit):
-        self.status = 'init'
+    def __init__(
+        self,
+        worker_args,
+        worker_kwargs,
+        worker_start_args,
+        silence_logs,
+        on_exit,
+        worker,
+        env,
+    ):
+        self.status = "init"
         self.silence_logs = silence_logs
         self.worker_args = worker_args
         self.worker_kwargs = worker_kwargs
         self.worker_start_args = worker_start_args
         self.on_exit = on_exit
         self.process = None
+        self.Worker = worker
+        self.env = env
 
         # Initialized when worker is ready
         self.worker_dir = None
@@ -338,9 +402,9 @@ class WorkerProcess(object):
         Ensure the worker process is started.
         """
         enable_proctitle_on_children()
-        if self.status == 'running':
+        if self.status == "running":
             raise gen.Return(self.status)
-        if self.status == 'starting':
+        if self.status == "starting":
             yield self.running.wait()
             raise gen.Return(self.status)
 
@@ -350,27 +414,31 @@ class WorkerProcess(object):
 
         self.process = AsyncProcess(
             target=self._run,
-            kwargs=dict(worker_args=self.worker_args,
-                        worker_kwargs=self.worker_kwargs,
-                        worker_start_args=self.worker_start_args,
-                        silence_logs=self.silence_logs,
-                        init_result_q=self.init_result_q,
-                        child_stop_q=self.child_stop_q,
-                        uid=uid),
+            kwargs=dict(
+                worker_args=self.worker_args,
+                worker_kwargs=self.worker_kwargs,
+                worker_start_args=self.worker_start_args,
+                silence_logs=self.silence_logs,
+                init_result_q=self.init_result_q,
+                child_stop_q=self.child_stop_q,
+                uid=uid,
+                Worker=self.Worker,
+                env=self.env,
+            ),
         )
         self.process.daemon = True
         self.process.set_exit_callback(self._on_exit)
         self.running = Event()
         self.stopped = Event()
-        self.status = 'starting'
+        self.status = "starting"
         yield self.process.start()
         msg = yield self._wait_until_connected(uid)
         if not msg:
             raise gen.Return(self.status)
-        self.worker_address = msg['address']
-        self.worker_dir = msg['dir']
+        self.worker_address = msg["address"]
+        self.worker_dir = msg["dir"]
         assert self.worker_address
-        self.status = 'running'
+        self.status = "running"
         self.running.set()
 
         init_q.close()
@@ -388,27 +456,25 @@ class WorkerProcess(object):
         if exitcode == 255:
             return "Worker process %d was killed by unknown signal" % (pid,)
         elif exitcode >= 0:
-            return "Worker process %d exited with status %d" % (pid, exitcode,)
+            return "Worker process %d exited with status %d" % (pid, exitcode)
         else:
-            return "Worker process %d was killed by signal %d" % (pid, -exitcode,)
+            return "Worker process %d was killed by signal %d" % (pid, -exitcode)
 
     def is_alive(self):
         return self.process is not None and self.process.is_alive()
 
     @property
     def pid(self):
-        return (self.process.pid
-                if self.process and self.process.is_alive()
-                else None)
+        return self.process.pid if self.process and self.process.is_alive() else None
 
     def mark_stopped(self):
-        if self.status != 'stopped':
+        if self.status != "stopped":
             r = self.process.exitcode
             assert r is not None
             if r != 0:
                 msg = self._death_message(self.process.pid, r)
                 logger.warning(msg)
-            self.status = 'stopped'
+            self.status = "stopped"
             self.stopped.set()
             # Release resources
             self.process.close()
@@ -432,28 +498,31 @@ class WorkerProcess(object):
         loop = IOLoop.current()
         deadline = loop.time() + timeout
 
-        if self.status == 'stopped':
+        if self.status == "stopped":
             return
-        if self.status == 'stopping':
+        if self.status == "stopping":
             yield self.stopped.wait()
             return
-        assert self.status in ('starting', 'running')
-        self.status = 'stopping'
+        assert self.status in ("starting", "running")
+        self.status = "stopping"
 
         process = self.process
-        self.child_stop_q.put({
-            'op': 'stop',
-            'timeout': max(0, deadline - loop.time()) * 0.8,
-            'executor_wait': executor_wait,
-        })
+        self.child_stop_q.put(
+            {
+                "op": "stop",
+                "timeout": max(0, deadline - loop.time()) * 0.8,
+                "executor_wait": executor_wait,
+            }
+        )
         self.child_stop_q.close()
 
         while process.is_alive() and loop.time() < deadline:
             yield gen.sleep(0.05)
 
         if process.is_alive():
-            logger.warning("Worker process still alive after %d seconds, killing",
-                           timeout)
+            logger.warning(
+                "Worker process still alive after %d seconds, killing", timeout
+            )
             try:
                 yield process.terminate()
             except Exception as e:
@@ -463,7 +532,7 @@ class WorkerProcess(object):
     def _wait_until_connected(self, uid):
         delay = 0.05
         while True:
-            if self.status != 'starting':
+            if self.status != "starting":
                 return
             try:
                 msg = self.init_result_q.get_nowait()
@@ -471,25 +540,35 @@ class WorkerProcess(object):
                 yield gen.sleep(delay)
                 continue
 
-            if msg['uid'] != uid:  # ensure that we didn't cross queues
+            if msg["uid"] != uid:  # ensure that we didn't cross queues
                 continue
 
-            if 'exception' in msg:
-                logger.error("Failed while trying to start worker process: %s",
-                             msg['exception'])
+            if "exception" in msg:
+                logger.error(
+                    "Failed while trying to start worker process: %s", msg["exception"]
+                )
                 yield self.process.join()
                 raise msg
             else:
                 raise gen.Return(msg)
 
     @classmethod
-    def _run(cls, worker_args, worker_kwargs, worker_start_args,
-             silence_logs, init_result_q, child_stop_q, uid):  # pragma: no cover
-        from distributed import Worker
-
+    def _run(
+        cls,
+        worker_args,
+        worker_kwargs,
+        worker_start_args,
+        silence_logs,
+        init_result_q,
+        child_stop_q,
+        uid,
+        env,
+        Worker,
+    ):  # pragma: no cover
+        os.environ.update(env)
         try:
             from dask.multiprocessing import initialize_worker_process
-        except ImportError:   # old Dask version
+        except ImportError:  # old Dask version
             pass
         else:
             initialize_worker_process()
@@ -505,10 +584,12 @@ class WorkerProcess(object):
         @gen.coroutine
         def do_stop(timeout=5, executor_wait=True):
             try:
-                yield worker._close(report=False,
-                                    nanny=False,
-                                    executor_wait=executor_wait,
-                                    timeout=timeout)
+                yield worker._close(
+                    report=False,
+                    nanny=False,
+                    executor_wait=executor_wait,
+                    timeout=timeout,
+                )
             finally:
                 loop.stop()
 
@@ -524,7 +605,7 @@ class WorkerProcess(object):
                     pass
                 else:
                     child_stop_q.close()
-                    assert msg.pop('op') == 'stop'
+                    assert msg.pop("op") == "stop"
                     loop.add_callback(do_stop, **msg)
                     break
 
@@ -541,13 +622,13 @@ class WorkerProcess(object):
                 yield worker._start(*worker_start_args)
             except Exception as e:
                 logger.exception("Failed to start worker")
-                init_result_q.put({'uid': uid, 'exception': e})
+                init_result_q.put({"uid": uid, "exception": e})
                 init_result_q.close()
             else:
                 assert worker.address
-                init_result_q.put({'address': worker.address,
-                                   'dir': worker.local_dir,
-                                   'uid': uid})
+                init_result_q.put(
+                    {"address": worker.address, "dir": worker.local_dir, "uid": uid}
+                )
                 init_result_q.close()
                 yield worker.wait_until_closed()
                 logger.info("Worker closed")
