@@ -11,8 +11,14 @@ except ImportError:
     from toolz import reduce
 
 from .compression import compressions, maybe_compress, decompress
-from .serialize import (serialize, deserialize, Serialize, Serialized,
-                        extract_serialize, msgpack_len_opts)
+from .serialize import (
+    serialize,
+    deserialize,
+    Serialize,
+    Serialized,
+    extract_serialize,
+    msgpack_len_opts,
+)
 from .utils import frame_split_size, merge_frames
 from ..utils import nbytes
 
@@ -20,18 +26,18 @@ _deserialize = deserialize
 
 
 try:
-    msgpack.loads(msgpack.dumps(''), raw=False, **msgpack_len_opts)
-    msgpack_opts = {'raw': False}
+    msgpack.loads(msgpack.dumps(""), raw=False, **msgpack_len_opts)
+    msgpack_opts = {"raw": False}
     msgpack_opts.update(msgpack_len_opts)
 except TypeError:
     # Backward compat with old msgpack (prior to 0.5.2)
-    msgpack_opts = {'encoding': 'utf-8'}
+    msgpack_opts = {"encoding": "utf-8"}
 
 
 logger = logging.getLogger(__name__)
 
 
-def dumps(msg, serializers=None, on_error='message', context=None):
+def dumps(msg, serializers=None, on_error="message", context=None):
     """ Transform Python message to bytestream suitable for communication """
     try:
         data = {}
@@ -43,56 +49,60 @@ def dumps(msg, serializers=None, on_error='message', context=None):
         if not data:  # fast path without serialized data
             return small_header, small_payload
 
-        pre = {key: (value.header, value.frames)
-               for key, value in data.items()
-               if type(value) is Serialized}
+        pre = {
+            key: (value.header, value.frames)
+            for key, value in data.items()
+            if type(value) is Serialized
+        }
 
-        data = {key: serialize(value.data,
-                               serializers=serializers,
-                               on_error=on_error,
-                               context=context)
-                for key, value in data.items()
-                if type(value) is Serialize}
+        data = {
+            key: serialize(
+                value.data, serializers=serializers, on_error=on_error, context=context
+            )
+            for key, value in data.items()
+            if type(value) is Serialize
+        }
 
-        header = {'headers': {},
-                  'keys': [],
-                  'bytestrings': list(bytestrings)}
+        header = {"headers": {}, "keys": [], "bytestrings": list(bytestrings)}
 
         out_frames = []
 
         for key, (head, frames) in data.items():
-            if 'lengths' not in head:
-                head['lengths'] = tuple(map(nbytes, frames))
-            if 'compression' not in head:
+            if "lengths" not in head:
+                head["lengths"] = tuple(map(nbytes, frames))
+            if "compression" not in head:
                 frames = frame_split_size(frames)
                 if frames:
                     compression, frames = zip(*map(maybe_compress, frames))
                 else:
                     compression = []
-                head['compression'] = compression
-            head['count'] = len(frames)
-            header['headers'][key] = head
-            header['keys'].append(key)
+                head["compression"] = compression
+            head["count"] = len(frames)
+            header["headers"][key] = head
+            header["keys"].append(key)
             out_frames.extend(frames)
 
         for key, (head, frames) in pre.items():
-            if 'lengths' not in head:
-                head['lengths'] = tuple(map(nbytes, frames))
-            head['count'] = len(frames)
-            header['headers'][key] = head
-            header['keys'].append(key)
+            if "lengths" not in head:
+                head["lengths"] = tuple(map(nbytes, frames))
+            head["count"] = len(frames)
+            header["headers"][key] = head
+            header["keys"].append(key)
             out_frames.extend(frames)
 
         for i, frame in enumerate(out_frames):
             if type(frame) is memoryview and frame.strides != (1,):
                 try:
-                    frame = frame.cast('b')
+                    frame = frame.cast("b")
                 except TypeError:
                     frame = frame.tobytes()
                 out_frames[i] = frame
 
-        return [small_header, small_payload,
-                msgpack.dumps(header, use_bin_type=True)] + out_frames
+        return [
+            small_header,
+            small_payload,
+            msgpack.dumps(header, use_bin_type=True),
+        ] + out_frames
     except Exception:
         logger.critical("Failed to Serialize", exc_info=True)
         raise
@@ -112,13 +122,13 @@ def loads(frames, deserialize=True, deserializers=None):
 
         header = frames.pop()
         header = msgpack.loads(header, use_list=False, **msgpack_opts)
-        keys = header['keys']
-        headers = header['headers']
-        bytestrings = set(header['bytestrings'])
+        keys = header["keys"]
+        headers = header["headers"]
+        bytestrings = set(header["bytestrings"])
 
         for key in keys:
             head = headers[key]
-            count = head['count']
+            count = head["count"]
             if count:
                 fs = frames[-count::][::-1]
                 del frames[-count:]
@@ -126,7 +136,7 @@ def loads(frames, deserialize=True, deserializers=None):
                 fs = []
 
             if deserialize or key in bytestrings:
-                if 'compression' in head:
+                if "compression" in head:
                     fs = decompress(head, fs)
                 fs = merge_frames(head, fs)
                 value = _deserialize(head, fs, deserializers=deserializers)
@@ -166,12 +176,12 @@ def dumps_msgpack(msg):
 
     fmt, payload = maybe_compress(payload)
     if fmt:
-        header['compression'] = fmt
+        header["compression"] = fmt
 
     if header:
         header_bytes = msgpack.dumps(header, use_bin_type=True)
     else:
-        header_bytes = b''
+        header_bytes = b""
 
     return [header_bytes, payload]
 
@@ -187,12 +197,14 @@ def loads_msgpack(header, payload):
     else:
         header = {}
 
-    if header.get('compression'):
+    if header.get("compression"):
         try:
-            decompress = compressions[header['compression']]['decompress']
+            decompress = compressions[header["compression"]]["decompress"]
             payload = decompress(payload)
         except KeyError:
-            raise ValueError("Data is compressed as %s but we don't have this"
-                             " installed" % str(header['compression']))
+            raise ValueError(
+                "Data is compressed as %s but we don't have this"
+                " installed" % str(header["compression"])
+            )
 
     return msgpack.loads(payload, use_list=False, **msgpack_opts)
