@@ -3,12 +3,14 @@ from distributed.utils_test import gen_cluster
 
 import toolz
 from tornado import gen
+import pytest
 
 
+@pytest.mark.xfail(reason="out of order execution")
 @gen_cluster(client=True)
 def test_basic(c, s, a, b):
     async def publish():
-        pub = Pub('a')
+        pub = Pub("a")
 
         i = 0
         while True:
@@ -17,7 +19,7 @@ def test_basic(c, s, a, b):
             i += 1
 
     def f(_):
-        sub = Sub('a')
+        sub = Sub("a")
         return list(toolz.take(5, sub))
 
     c.run_coroutine(publish, workers=[a.address])
